@@ -421,7 +421,7 @@ class VariableClAutopartitionDefaultFormat(Variable):
         availFS = set(self.Select('os_format_type',
                                   where='os_format_use',
                                   eq='yes'))
-        return list(sorted(allfs, availFS))
+        return list(sorted(allfs & availFS))
 
 
 class VariableClAutopartitionRootFormat(VariableClAutopartitionDefaultFormat):
