@@ -493,15 +493,6 @@ class VariableOsDeviceSize(ReadonlyVariable):
         return map(humanreadableSize,
                    self.Get())
 
-#############################################
-# Minimal bios boot size
-#############################################
-
-class VariableClMinimumBiosGrubSize(Variable):
-    """
-    Минимальный размер раздела bios_grub
-    """
-    value = str(9 * Sizes.M)
 
 #############################################
 # Disk variables
@@ -1982,7 +1973,10 @@ class VariableOsInstallBootloader(ReadonlyVariable):
         if self.Get('os_install_uefi_set') == 'on':
             return _("UEFI")
         else:
-            return ",".join(self.Get('os_install_mbr', humanreadable=True))
+            mbrs = self.Get('os_install_mbr', humanreadable=True)
+            if not mbrs:
+                return _("no")
+            return ",".join(mbrs)
 
 
 class VariableOsInstallBootDevices(ReadonlyVariable):
@@ -2233,7 +2227,7 @@ class VariableOsInstallMbr(LocationHelper, Variable):
                     )
                     if disk_id == 'EF02' and mbrDisk in disk_parent
                 )
-                bios_grub_size = self.Get('cl_minimum_bios_grub_size')
+                bios_grub_size = self.Get('cl_autopartition_bios_grub_size')
                 for bbsize in bbsizes:
                     minsize = "%dMb" % (int(bios_grub_size) / Sizes.M)
                     if not bbsize:
